package org.apache.commons.lang3.time;

package .tmp;

import java.text.ParsePosition;
import java.util.Calendar;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.apache.commons.lang3.time.FastDateParser;

abstract class PatternStrategy extends FastDateParser.Strategy {
  Pattern pattern;
  
  private PatternStrategy() {}
  
  void createPattern(StringBuilder regex) {
    createPattern(regex.toString());
  }
  
  void createPattern(String regex) {
    this.pattern = Pattern.compile(regex);
  }
  
  boolean isNumber() {
    return false;
  }
  
  boolean parse(FastDateParser parser, Calendar calendar, String source, ParsePosition pos, int maxWidth) {
    Matcher matcher = this.pattern.matcher(source.substring(pos.getIndex()));
    if (!matcher.lookingAt()) {
      pos.setErrorIndex(pos.getIndex());
      return false;
    } 
    pos.setIndex(pos.getIndex() + matcher.end(1));
    setCalendar(parser, calendar, matcher.group(1));
    return true;
  }
  
  public String toString() {
    return getClass().getSimpleName() + " [pattern=" + this.pattern + "]";
  }
  
  abstract void setCalendar(FastDateParser paramFastDateParser, Calendar paramCalendar, String paramString);
}
